# Wind farm load surrogate

[![pipeline status](https://gitlab.windenergy.dtu.dk/surrogate-models/wind-farm-loads/badges/main/pipeline.svg)](https://gitlab.windenergy.dtu.dk/surrogate-models/wind-farm-loads/-/commits/main)
[![coverage report](https://gitlab.windenergy.dtu.dk/surrogate-models/wind-farm-loads/badges/main/coverage.svg)](https://gitlab.windenergy.dtu.dk/surrogate-models/wind-farm-loads/-/commits/main)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Poetry](https://img.shields.io/endpoint?url=https://python-poetry.org/badge/v0.json)](https://python-poetry.org/)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.17542983.svg)](https://doi.org/10.5281/zenodo.17542983)
[![License: MIT](https://img.shields.io/badge/License-MIT-green.svg)](https://opensource.org/licenses/MIT)

Couple load surrogate models with PyWake and Floris.

The documentation is available at https://surrogate-models.pages.windenergy.dtu.dk/wind-farm-loads/

This package is deployed to PyPi at https://pypi.org/project/wind-farm-loads/
